@@ -1,6 +1,6 @@
 package MooseX::StrictConstructor::Trait::Class;
 BEGIN {
-  $MooseX::StrictConstructor::Trait::Class::VERSION = '0.13';
+  $MooseX::StrictConstructor::Trait::Class::VERSION = '0.14';
 }
 
 use Moose::Role;
@@ -8,7 +8,6 @@ use Moose::Role;
 use namespace::autoclean;
 
 use B ();
-use Carp ();
 
 around '_inline_BUILDALL' => sub {
     my $orig = shift;
@@ -28,11 +27,22 @@ around '_inline_BUILDALL' => sub {
         'my %attrs = (' . ( join ' ', @attrs ) . ');',
         'my @bad = sort grep { !$attrs{$_} } keys %{ $params };',
         'if (@bad) {',
-            'Carp::confess "Found unknown attribute(s) passed to the constructor: @bad";',
+            'Moose->throw_error("Found unknown attribute(s) passed to the constructor: @bad");',
         '}',
     );
 };
 
+# If the base class role is applied first, and then a superclass is added, we
+# lose the role.
+after superclasses => sub {
+    my $self = shift;
+    return if not @_;
+    Moose::Util::MetaRole::apply_base_class_roles(
+        for   => $self->name,
+        roles => ['MooseX::StrictConstructor::Role::Object'],
+    );
+};
+
 1;
 
 # ABSTRACT: A role to make immutable constructors strict
@@ -47,7 +57,7 @@ MooseX::StrictConstructor::Trait::Class - A role to make immutable constructors
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
@@ -61,7 +71,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is Copyright (c) 2011 by Dave Rolsky.
 
 This is free software, licensed under:
 
